@@ -1,3 +1,3 @@
 from concordancer.server import download_query_interface
 
-download_query_interface(force=False)
\ No newline at end of file
+download_query_interface(force=True)
\ No newline at end of file
